@@ -5,6 +5,7 @@ use DBD::Pg ':async';
 use IO::Handle;
 use Mojo::IOLoop;
 use Mojo::Pg::Results;
+use Mojo::Pg::Transaction;
 
 has [qw(dbh pg)];
 has max_statements => 10;
@@ -16,9 +17,12 @@ sub DESTROY {
 
 sub backlog { scalar @{shift->{waiting} || []} }
 
-sub begin { shift->_dbh(begin_work => @_) }
-
-sub commit { shift->_dbh(commit => @_) }
+sub begin {
+  my $self = shift;
+  my $dbh  = $self->dbh;
+  $dbh->begin_work;
+  return Mojo::Pg::Transaction->new(dbh => $dbh);
+}
 
 sub disconnect {
   my $self = shift;
@@ -27,7 +31,11 @@ sub disconnect {
   $self->dbh->disconnect;
 }
 
-sub do { shift->_dbh(do => @_) }
+sub do {
+  my $self = shift;
+  $self->dbh->do(@_);
+  return $self;
+}
 
 sub is_listening { !!keys %{shift->{listen} || {}} }
 
@@ -45,7 +53,8 @@ sub listen {
 
 sub notify {
   my ($self, $name, $payload) = @_;
-  $self->query('select pg_notify(?, ?)', $name, $payload) and return $self;
+  $self->query('select pg_notify(?, ?)', $name, $payload);
+  return $self;
 }
 
 sub ping { shift->dbh->ping }
@@ -66,8 +75,6 @@ sub query {
   $self->$_ for qw(_next _watch);
 }
 
-sub rollback { shift->_dbh(rollback => @_) }
-
 sub unlisten {
   my ($self, $name) = @_;
 
@@ -80,12 +87,6 @@ sub unlisten {
   return $self;
 }
 
-sub _dbh {
-  my ($self, $method) = (shift, shift);
-  $self->dbh->$method(@_);
-  return $self;
-}
-
 sub _dequeue {
   my ($self, $async, $query) = @_;
 
@@ -224,15 +225,16 @@ Number of waiting non-blocking queries.
 
 =head2 begin
 
-  $db = $db->begin;
+  my $tx = $db->begin;
 
-Begin transaction.
+Begin transaction and return L<Mojo::Pg::Transaction> object, which will
+automatically roll back the transaction unless
+L<Mojo::Pg::Transaction/"commit"> bas been called before it is destroyed.
 
-=head2 commit
-
-  $db = $db->commit;
-
-Commit transaction.
+  my $tx = $db->begin;
+  $db->query('insert into names values (?)', 'Baerbel');
+  $db->query('insert into names values (?)', 'Wolfgangl');
+  $tx->commit;
 
 =head2 disconnect
 
@@ -288,12 +290,6 @@ performance. You can also append a callback to perform operation non-blocking.
   });
   Mojo::IOLoop->start unless Mojo::IOLoop->is_running;
 
-=head2 rollback
-
-  $db = $db->rollback;
-
-Rollback transaction.
-
 =head2 unlisten
 
   $db = $db->unlisten('foo');
